@@ -12,7 +12,14 @@ txtplot(runif(100), runif(100))
 a <- seq(0, 3, length=11)
 b <- exp(-a)
 txtplot(a, b, pch="o")
+txtcurve(x/(x+0.1), 0, 1, xlab = "Dose", ylab="Response")
 
 txtplot(a, b, xlim = c(1,2), ylim = c(0,1))
 
 txtboxplot(rexp(100), xlab = "waiting time")
+
+set.seed(1)
+txtplot(runif(10000,0,115000),100001:110000)
+txtplot(runif(10000,-115000,0), seq(1,9,length=10000))
+txtboxplot(runif(10000,0,115000))
+txtboxplot(runif(10000,-115000.0))
